| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeiaqmp7kocbfdboksayeqhkbrynvlfzsx4uy4x6nohywnmaig4an7u` | A protocol for ABCI requests and responses.                                                                                |
| protocol/valory/tendermint/0.1.0                              | `bafybeig4mi3vmlv5zpbjbfuzcgida6j5f2nhrpedxicmrrfjweqc5r7cra` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeiftxi2qhreewgsc5wevogi7yc5g6hbcbo4uiuaibauhv3nhfcdtvm` | A protocol specification for IPFS requests and responses.                                                                  |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeiafghfcxrg3apccnrvvw7tfgjbopedbfevmhepw2reyhyertxrilm` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeiepywewigowj533f55orx7oys3kk5lgdc247p2267scqfyp4gnqle` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeignghdk7oqvyg722gz66tbuj2vj4vkatguj4b6lf5fqzqxkktcke4` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeicqf5y3kj42ow45hjcmnglose5n7bwpm2zl3ufuuevou24ewmgbde` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeibmqewfh5wnayopneyv4vx35n5k7loavzmcazyevntdoskw7vasom` | Service Manager contract                                                                                                   |
| contract/valory/service_registry/0.1.0                        | `bafybeigrfupd7lo6aet376rwluqgm33jfghibkbvumfsdgrymqxoopqydq` | Service Registry contract                                                                                                  |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeiag5jjj5c66skkbjnxcjngeufhtcvcpnbnjlgox5mtuo2tk4w3ohi` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| contract/valory/multisend/0.1.0                               | `bafybeig5byt5urg2d2bsecufxe5ql7f4mezg3mekfleeh32nmuusx66p4y` | MultiSend contract                                                                                                         |
| contract/valory/erc20/0.1.0                                   | `bafybeib7ctk3deleyxayrqvropewefr2muj4kcqe3t3wscak25bjmxnqwe` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/service_registry_token_utility/0.1.0          | `bafybeifdia2y5546tvk6xzxeaqzf2n5n7dutj2hdzbgenxohaqhjtnjqm4` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/squads_multisig/0.1.0                         | `bafybeigv5o6qj2qrjm7mwsfiypy5foagcrigb6npyk2o4keyqae5tm5rcm` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/multicall2/0.1.0                              | `bafybeiajy43qpdhzzrkjuofuuai7uvkasiua4cupudgjcvztcj4p464gsy` | The MakerDAO multicall2 contract.                                                                                          |
| connection/valory/abci/0.1.0                                  | `bafybeihhtx7t5fsxaoajzq5nm4hrq57smigx7gqv35bss766txaaffjmsa` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeifqca6e232lbvwrjhd7ioh43bo3evxfkpumdvcr6re2sdwjuntgna` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeiet6nuzoas2jau66xpkx52comm7zijxh7d5kpvwoyrd6y2t3j46se` | IPFS e2e testing application.                                                                                              |
| skill/valory/abstract_abci/0.1.0                              | `bafybeiedikuvfpdx7xhyrxcpp6ywi2d6qf6uqvlwmhgcal7qhw5duicvym` | The abci skill provides a template of an ABCI application.                                                                 |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeia7msuvsouwcky263k6lup5hwcj73pka4pepkgyii6sya2wfawqvy` | abstract round-based ABCI application                                                                                      |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeihfrdgfhu7ijjorvktjplfa4aq3b5as4dtwmkgl6nhy2oz4ayidfu` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeihwkqc6klqrk247esh4cumfphosx3yadullxhmrrkovzg2rward5y` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeibd5divbbng3klkxlkzfwmwdc7imobcymfx57lf3owbyf7we7xdem` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeifw36rnniyjay4f3af6jtfxpeycm5nu4zm4ejoutsk4yh2rv24ysm` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeih5cllexnfi5rudvk5m4wqelwme2sqafkdrre74rjtszrwwbqsbke` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeih2hz7bvltfnlw7cgjrwgjdw3xgejwcnkxry7i6ajcspwcw2hrb3e` | A client for the ABCI counter application.                                                                                 |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeiagkqvfxcdnqysclkjmoqh7hn27dnuiwsuilpwromwur65zwjcsbu` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeibtyncgsjzv43kysvcfypffoqb2ogcynwpdrexozorsj6a6azujye` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeiauqgm245ccclim4r6mtcrcyhgflxion6tzqa42qa4l6dgnxpu5gm` | ABCI application for testing the ABCI connection.                                                                          |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeih6p3w6uucdpzdupn2qrzubyc6yxhmumcspvy4qkipke4tm3puzxe` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/slashing_abci/0.1.0                              | `bafybeigd4uqbpgaqnuyl5eiy65wsmgfw3ciinah5mibbqxrvib5h6d54w4` | Slashing skill.                                                                                                            |
| skill/valory/offend_abci/0.1.0                                | `bafybeibl4fsrdk4jwkpivj5rvgebn2qhkcrcfipbfa3zxwdlskihu4itey` | Offend ABCI application.                                                                                                   |
| skill/valory/offend_slash_abci/0.1.0                          | `bafybeiel3afyiscmjwll6k64ujtpalznxzfun2htbbb2sty3zpe6uit73u` | ABCI application used in order to test the slashing abci                                                                   |
| skill/valory/squads_transaction_settlement_abci/0.1.0         | `bafybeihwrttcvn2n57lrigcvwqcnp6hjs37snu7sz6oiroym6ia7434jv4` | ABCI application for transaction settlement.                                                                               |
| skill/valory/test_solana_tx_abci/0.1.0                        | `bafybeifkg4pwtjnhnfzphohxtjolesvbsb4a5cvkrhctks4ewwfiix7dh4` | SOLANA e2e testing application.                                                                                            |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeih47wzycrpkq4tfwjy72frectdlbb7fpp4xpoxkv7yafxuxvcyep4` | Agent for testing the ABCI connection.                                                                                     |
| agent/valory/abstract_abci/0.1.0                              | `bafybeial4n23lkhqrkas3gaoo3kdv6bt6355dhy3wbyciaxyifbgw3d3am` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeidrq2davsmagw7hy5orgbi6pgzb7vi7vi2bhkwzwhk7q7gj3kfs7y` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeib7oaokst3drdhypvyubw53golb6bxwe2dgimthgetkzgjoucvoai` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/register_reset/0.1.0                             | `bafybeihjishbkx2sdnxvyxviqnjsi2bx6nhy4etc5wike7zj43ip5pinge` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeibn4wcx4ura5unz2j5qlhdse6cyikpe6t6v22my7oiff7ilpxjfxa` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeief5qmq24hugwtnomyrkfjcqupgr75dd44xrqiaqhbdwpx3plks2a` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeic3itknzi7yu645ouvxdlxiremzdobzozf6to3embpwnuboziphq4` | Agent for testing the ABCI connection.                                                                                     |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeibrblrrjbopwwl2l6denbmzgyeke4gx6vm4ru362hhfi6rqsviyyq` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| agent/valory/offend_slash/0.1.0                               | `bafybeia2yb5mjppgdev6zbuaj2vhklcrrl76f3fkirdtdblc6wnmu75xem` | Offend and slash to test the slashing feature.                                                                             |
| agent/valory/solana_transfer_agent/0.1.0                      | `bafybeiacuwvoqdcq2dpzzjwkvv63c4wruzhni35yxvdmgx2zerkr3522uq` | Register terminate to test the termination feature.                                                                        |
| service/valory/counter/0.1.0                                  | `bafybeiasje4n6dg6tz6obqg4uzxcbevl2vea3ihtago7nsrsu5jo4t42dq` | A set of agents incrementing a counter                                                                                     |
| service/valory/register_reset/0.1.0                           | `bafybeibuw6froocwrj7qffbce7ruy4n3shfamcxnxf3azphkexyxenwp7a` | Test and debug tendermint reset mechanism.                                                                                 |
| protocol/open_aea/signing/1.0.0                               | `bafybeihv62fim3wl2bayavfcg3u5e5cxu3b7brtu4cn5xoxd6lqwachasi` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeidluaoeakae3exseupaea4i3yvvk5vivyt227xshjlffywwxzcxqe` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeifugzl63kfdmwrxwphrnrhj7bn6iruxieme3a4ntzejf6kmtuwmae` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeihdk6psr4guxmbcrc26jr2cbgzpd5aljkqvpwo64bvaz7tdti2oni` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeidgu7o5llh26xp3u3ebq3yluull5lupiyeu6iooi2xyymdrgnzq5i` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeihi772xgzpqeipp3fhmvpct4y6e6tpjp4sogwqrnf3wqspgeilg4u` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeig7woeog4srdby75hpjkmx4rhpkzncbf4h2pm5r6varsp26pf2uhu` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeid3xg5k2ol5adflqloy75ibgljmol6xsvzvezebsg7oudxeeolz7e` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
